# Generated by Django 2.2 on 2021-04-09 16:46

from django.db import migrations, models
import django.db.models.deletion
import flowerhub.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DomainName',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('category', models.SmallIntegerField(choices=[(3, 'a'), (1, 'mx'), (2, 'cname'), (4, 'ptr'), (5, 'txt'), (6, 'srv'), (7, 'aaaa'), (10, 'sshfp'), (8, 'webproxy')], help_text='What category of domain name record do you want? An A record is commonly used for setting up web sites. An MX record is used to configure where your email should go. A TXT record can be used for SPF or DKIM. A WEBPROXY is a custom type used only for web sites hosted with us.')),
                ('label', models.CharField(blank=True, help_text='The sub domain, the part before the first dot. Often left blank for MX records and for A records designating the web site.', max_length=254, validators=[flowerhub.models.valid_domain_label])),
                ('ip_address', models.GenericIPAddressField(blank=True, null=True, verbose_name='IP Address')),
                ('ttl', models.PositiveIntegerField(default=3600, help_text='The time to live indicates how many seconds it will take before changes to the record are fully propagated. The number is in seconds - 3600 seconds, or one hour, is recommended. Must be 300 or greater', validators=[flowerhub.models.valid_domain_ttl], verbose_name='Time to live')),
                ('server_name', models.CharField(blank=True, help_text='Server name is required for MX and SRV records.', max_length=254, validators=[flowerhub.models.valid_domain_server_name])),
                ('txt', models.CharField(blank=True, help_text='The text to associate with this domain. Required for TXT records.', max_length=254, verbose_name='Text')),
                ('distance', models.PositiveIntegerField(default=0, help_text='If you have more than one MX record specified, the one with the smallest distance is chosen first.', verbose_name='Distance')),
                ('port', models.PositiveIntegerField(default=0)),
                ('weight', models.PositiveIntegerField(default=0)),
                ('sshfp_algorithm', models.PositiveIntegerField(choices=[(0, ''), (1, 'rsa'), (2, 'dsa'), (3, 'ecdsa'), (4, 'ed25519')], default=0, help_text='The algorithm to use, note: dsa is considered insecure and should not be used.', validators=[flowerhub.models.valid_sshfp_algorithm], verbose_name='SSH Fingerprint Algorithm')),
                ('sshfp_type', models.PositiveIntegerField(choices=[(0, ''), (2, 'sha256'), (1, 'sha1')], default=0, help_text='The encryption type, note: sha1 is considered insecure and should not be used.', validators=[flowerhub.models.valid_sshfp_type], verbose_name='SSH Fingerprint Type')),
                ('sshfp_data', models.CharField(blank=True, help_text="The SSH Fingerprint associated with this domain (typically generated via 'ssh_keygen -r').", max_length=254, verbose_name='SSH Fingerprint data')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DomainZone',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('domain', models.CharField(max_length=254, unique=True, validators=[flowerhub.models.valid_domain_zone])),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EmailAlias',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('local', models.CharField(help_text='The portion of the email address before the @ sign.', max_length=254, validators=[flowerhub.models.valid_user_portion])),
                ('domain_name', models.CharField(help_text='The portion of the email address after the @ sign.', max_length=254, validators=[flowerhub.models.valid_domain_name])),
                ('target', models.TextField(help_text='Enter up to 10 space separated email addresses that should receive all email sent to the alias address.', validators=[flowerhub.models.valid_space_separated_email_addresses], verbose_name='Target addresses')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EmailMailbox',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('local', models.CharField(help_text='The portion of the email address before the @ sign.', max_length=254, validators=[flowerhub.models.valid_user_portion])),
                ('domain_name', models.CharField(help_text='The portion of the email address after the @ sign.', max_length=254, validators=[flowerhub.models.valid_domain_name])),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Feedback',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rank', models.SmallIntegerField(choices=[(0, 'Choose one'), (1, 'Good'), (2, 'Medium'), (3, 'Bad')], default=0, help_text='What is your overall impression? Required - please choose one.', validators=[flowerhub.models.valid_rank])),
                ('comments', models.TextField(blank=True, help_text='Optionally, Please let us know what you think and if you have any suggestions for improvements.')),
            ],
        ),
        migrations.CreateModel(
            name='Login',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('username', models.CharField(help_text='Please use only lower case letters, numbers, periods, and dashes.', max_length=254, unique=True, validators=[flowerhub.models.valid_username])),
                ('password', models.CharField(blank=True, max_length=254, validators=[flowerhub.models.valid_password])),
                ('uid', models.PositiveIntegerField(blank=True, unique=True)),
                ('first_name', models.CharField(max_length=64)),
                ('last_name', models.CharField(blank=True, max_length=64, verbose_name='Last Name (optional)')),
                ('shell_access', models.BooleanField(default=False, help_text='Shell Access means this user will be able to login to one of our servers to copy files or run commands. Shell access is typically only required for users who maintain web sites.')),
                ('ssh_key', models.TextField(blank=True, help_text='An SSH public key allows users to login to our servers without exchanging a password. Please upload the public key, not the private one.', validators=[flowerhub.models.valid_ssh_public_key_file], verbose_name='SSH Public Key')),
                ('nextcloud_access', models.BooleanField(default=False, help_text='Nextcloud is our document sharing, calendar and contacts application that is available via <a href="https://share.mayfirst.org/">share.mayfirst.org</a>.')),
                ('nextcloud_quota', models.PositiveIntegerField(default=5000, help_text='Enter the Nextcloud disk quota for this user in megabytes.')),
                ('discourse_access', models.BooleanField(default=False, help_text='Discourse is our online community forum site available via <a href="https://comment.mayfirst.org/">comment.mayfirst.org</a>')),
                ('xmpp_access', models.BooleanField(default=False, help_text='XMPP is our instant messanger program - for instructions, please see our <a href="https://support.mayfirst.org/wiki/how-tos/jabber">online help page</a>.', verbose_name='XMPP Access')),
                ('livestreaming_access', models.BooleanField(default=False, help_text='All members can live video stream directly from their cell phones via <a href="https://live.mayfirst.org">live.mayfirst.org</a>.')),
                ('auto_response_action', models.SmallIntegerField(choices=[(1, 'Do not send auto response'), (2, 'Send auto response and accept incoming email'), (3, 'Send auto response and discard incoming email')], default=1)),
                ('auto_response_reply_from', models.EmailField(blank=True, help_text='Enter the email address the auto response should come from.', max_length=254)),
                ('auto_response', models.TextField(blank=True)),
                ('recovery_email', models.EmailField(blank=True, help_text='Enter an email address that will be sent a reset link if you ever lose your password.', max_length=254)),
                ('mailbox_quota', models.PositiveIntegerField(default=1000, help_text='Enter the size limit of the mailbox in megabytes.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MailingList',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('listname', models.CharField(help_text='The listname is the portion of the email list that comes before the @ sign. If your list address is support@lists.mayfirst.org, the list name would be: support.', max_length=64, unique=True, validators=[flowerhub.models.valid_user_portion])),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Member',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='Friendly name, can be changed later.', max_length=64, unique=True)),
                ('category', models.SmallIntegerField(choices=[(1, 'basic'), (2, 'standard')], default=2, help_text='Basic memberships gets one login and one email address, standard gets full array of resources.')),
                ('disk_quota', models.PositiveIntegerField(default=50000, help_text='Total disk space for the entire membership, in MB.')),
                ('is_active', models.BooleanField(default=True, help_text='Whether or not the membership is active, when disabled, all related resources are disabled.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MysqlDatabase',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('name', models.CharField(max_length=64, unique=True, validators=[flowerhub.models.valid_mysql_database])),
                ('member', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Partition',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_default', models.BooleanField(db_index=True, default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Petal',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.CharField(help_text='The full URL, including schema and port, that will listen for new requests sent by the flower hub.', max_length=254)),
                ('hostname', models.CharField(help_text='The fully qualified domain name of the host that will be used by proxy servers to locate the petal.', max_length=64, unique=True)),
                ('category', models.SmallIntegerField(choices=[(1, 'ldap'), (2, 'nsauth'), (3, 'nscache'), (4, 'shell'), (5, 'webstore'), (6, 'webproxy'), (7, 'mailstore'), (8, 'mailcf'), (9, 'mailmx'), (10, 'mailrelay'), (11, 'test')], db_index=True)),
                ('is_default', models.BooleanField(db_index=True, default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Website',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('label', models.CharField(help_text="Required. Enter a short (32 characters), descriptive label for this site, like 'Live site' or 'Coalition site'. You can always change it later.", max_length=32)),
                ('tls', models.BooleanField(default=True, help_text='Turn on for https, turn off to use http only.', verbose_name='Encryption')),
                ('relative_document_root', models.CharField(blank=True, help_text='Optionally, set a sub-directory of your website directory as your document root.', max_length=254, validators=[flowerhub.models.valid_path])),
                ('logging', models.SmallIntegerField(choices=[(0, 'Disable logging'), (1, 'Error logging only'), (2, 'Access and error logging')], default=2, help_text='For more privacy, you can disable logging. For trouble-shooting or to chart your site usage, you will want logging enabled.')),
                ('php_version', models.SmallIntegerField(choices=[(1, 'PHP 7.2'), (2, 'PHP 7.3')], default=2, verbose_name='PHP version')),
                ('settings', models.TextField(blank=True, help_text='Optionally, enter additional apache configuration settings (most sites do not need any additional settings).', validators=[flowerhub.models.valid_website_settings])),
                ('website_app', models.SmallIntegerField(choices=[(0, 'No thanks'), (1, 'Drupal'), (2, 'WordPress')], default=0, help_text="Optionally, automatically install a website app and allow May First to manage it's security by auto-upgrading on a daily basis. Note: If you plan to use git to manage your site, or otherwise want more control over the upgrades, do not choose this option.")),
                ('website_app_email', models.EmailField(blank=True, help_text="Set your website app's initial admin user to this address. Required when creating a website app.", max_length=254)),
                ('php_processes', models.SmallIntegerField(default=12, help_text='Limit the number of PHP processes your site may consume. The max is 12. Set to 0 to disable PHP.', verbose_name='PHP processes')),
                ('max_memory', models.PositiveIntegerField(default=256, help_text='PHP memory limit in Mb, contact support if you need more than 512')),
                ('tls_redirect', models.BooleanField(default=True, help_text='This setting is ignored on http only sites.', verbose_name='Automatically redirect to https?')),
                ('tls_custom', models.BooleanField(default=False, help_text="Check this box to use your own https certificate and key. Please first upload them to the tls directory and name them privkey.pem and fullchain.pem. If left unchecked, a free Let's Encrypt certificate will be automatically generated.", verbose_name='Custom TLS certificate and key')),
                ('cgi', models.BooleanField(default=False, help_text='Do you plan to run CGI programs? This setting is not needed and should be off for PHP web sites. If you do need CGI, please place scripts in the cgi-bin directory not in the regular web site directory.', verbose_name='CGI')),
                ('proxy_settings', models.TextField(blank=True, help_text='Optionally, provide additional settings for the website proxy (only accessible to admins for now).')),
                ('disk_quota', models.PositiveIntegerField(default=5000, help_text='Enter the disk quota for this web site megabytes.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='WebsiteRunner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_status', models.SmallIntegerField(choices=[(1, 'queued'), (2, 'in progress'), (3, 'active'), (4, 'disabled'), (5, 'deleted')], db_index=True, default=1)),
                ('desired_status', models.SmallIntegerField(choices=[(3, 'active'), (4, 'disabled'), (5, 'deleted')], default=3)),
                ('nonce', models.CharField(help_text='A random string used to authenticate the petal response after attempting to create/edit/delete the resource on the petal.', max_length=64)),
                ('nonce_created', models.DateTimeField(auto_now_add=True, help_text='The date/time the nonce was created.')),
                ('nonce_consumed', models.DateTimeField(blank=True, help_text='The date/time the nonce was used.', null=True)),
                ('data', models.TextField(help_text='A text representation of the resource fields and values to be created.')),
                ('petal_action', models.SmallIntegerField(choices=[(1, 'No operation required.'), (2, 'Create or update LDAP login'), (3, 'Delete LDAP login'), (4, 'Disable LDAP login'), (5, 'Add email address to LDAP record'), (7, 'Remove or disable email address from LDAP record.'), (8, 'Remove or disable last email address from LDAP record.'), (9, 'Create or update a domain zone.'), (10, 'Delete a domain zone.'), (12, 'Ensure Maildir exists.'), (13, 'Delete Maildir.'), (6, 'Add email domain.'), (11, 'Remove email domain.'), (14, 'Add email alias.'), (15, 'Remove email alias.'), (16, 'Create website on origin server.'), (17, 'Disable website on origin server.'), (18, 'Delete website on origin server.')], help_text='The class responsible for implementing this action on the petal.')),
                ('error', models.CharField(blank=True, help_text='Any errors encountered when creating the resource.', max_length=254)),
                ('is_active', models.BooleanField(default=True, help_text='When a resource is re-edited, all previous runners are retired so we always know which ones are active.')),
                ('modified_by', models.CharField(blank=True, help_text='String username of the user who modified this record.', max_length=64)),
                ('petal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Petal')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.Website')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='WebsiteLogin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('login', models.ForeignKey(help_text='The id of the login record.', limit_choices_to={'shell_access': True}, on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Login')),
                ('website', models.ForeignKey(help_text='The id of the website record.', on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Website')),
            ],
        ),
        migrations.CreateModel(
            name='WebsiteDomainName',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('domain_name', models.ForeignKey(help_text='The id of the domain name.', limit_choices_to={'category': 8}, on_delete=django.db.models.deletion.CASCADE, to='flowerhub.DomainName')),
                ('website', models.ForeignKey(help_text='The id of the web site.', on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Website')),
            ],
        ),
        migrations.AddField(
            model_name='website',
            name='domain_names',
            field=models.ManyToManyField(help_text='Required. Select all domains that should take you to this web site. Only WEBPROXY domain names are availabe.', through='flowerhub.WebsiteDomainName', to='flowerhub.DomainName'),
        ),
        migrations.AddField(
            model_name='website',
            name='logins',
            field=models.ManyToManyField(help_text='Required. Select all the users that should be able to update your web site (SFTP access). You can also type the complete username of a login from a different membership and grant that user access.', through='flowerhub.WebsiteLogin', to='flowerhub.Login'),
        ),
        migrations.AddField(
            model_name='website',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member'),
        ),
        migrations.AddField(
            model_name='website',
            name='partition',
            field=models.ForeignKey(blank=True, help_text="The partition holding this website's data. Set automatically to default if left blank, only change-able by admins.", limit_choices_to=models.Q(petal__category=5), null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='websites', to='flowerhub.Partition'),
        ),
        migrations.AddField(
            model_name='website',
            name='petals',
            field=models.ManyToManyField(through='flowerhub.WebsiteRunner', to='flowerhub.Petal'),
        ),
        migrations.AddField(
            model_name='website',
            name='website_store',
            field=models.ForeignKey(blank=True, help_text='The canonical website host holding this web site. Set automatically to default if left blank, only change-able by admins.', limit_choices_to={'category': 5}, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='websites', to='flowerhub.Petal'),
        ),
        migrations.CreateModel(
            name='PasswordReset',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('expiration_date', models.DateTimeField(null=True)),
                ('code', models.CharField(max_length=64)),
                ('notify', models.BooleanField(default=False)),
                ('login', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Login')),
            ],
        ),
        migrations.AddField(
            model_name='partition',
            name='petal',
            field=models.ForeignKey(blank=True, limit_choices_to=models.Q(('category', 5), ('category', 7), _connector='OR'), null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.Petal'),
        ),
        migrations.CreateModel(
            name='MysqlUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('user', models.CharField(max_length=16, unique=True, validators=[flowerhub.models.valid_mysql_user])),
                ('password', models.CharField(help_text='Database passwords are randomly chosen for you and cannot be entered manually. A password is only required when creating a new record.', max_length=254, validators=[flowerhub.models.valid_password])),
                ('permission', models.SmallIntegerField(choices=[(1, 'Read and write access'), (2, 'Read only access')], default=1, help_text='Either 1 for read and write access or 2 for read only access.')),
                ('member', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member')),
                ('mysql_database', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.MysqlDatabase')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MysqlDatabaseRunner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_status', models.SmallIntegerField(choices=[(1, 'queued'), (2, 'in progress'), (3, 'active'), (4, 'disabled'), (5, 'deleted')], db_index=True, default=1)),
                ('desired_status', models.SmallIntegerField(choices=[(3, 'active'), (4, 'disabled'), (5, 'deleted')], default=3)),
                ('nonce', models.CharField(help_text='A random string used to authenticate the petal response after attempting to create/edit/delete the resource on the petal.', max_length=64)),
                ('nonce_created', models.DateTimeField(auto_now_add=True, help_text='The date/time the nonce was created.')),
                ('nonce_consumed', models.DateTimeField(blank=True, help_text='The date/time the nonce was used.', null=True)),
                ('data', models.TextField(help_text='A text representation of the resource fields and values to be created.')),
                ('petal_action', models.SmallIntegerField(choices=[(1, 'No operation required.'), (2, 'Create or update LDAP login'), (3, 'Delete LDAP login'), (4, 'Disable LDAP login'), (5, 'Add email address to LDAP record'), (7, 'Remove or disable email address from LDAP record.'), (8, 'Remove or disable last email address from LDAP record.'), (9, 'Create or update a domain zone.'), (10, 'Delete a domain zone.'), (12, 'Ensure Maildir exists.'), (13, 'Delete Maildir.'), (6, 'Add email domain.'), (11, 'Remove email domain.'), (14, 'Add email alias.'), (15, 'Remove email alias.'), (16, 'Create website on origin server.'), (17, 'Disable website on origin server.'), (18, 'Delete website on origin server.')], help_text='The class responsible for implementing this action on the petal.')),
                ('error', models.CharField(blank=True, help_text='Any errors encountered when creating the resource.', max_length=254)),
                ('is_active', models.BooleanField(default=True, help_text='When a resource is re-edited, all previous runners are retired so we always know which ones are active.')),
                ('modified_by', models.CharField(blank=True, help_text='String username of the user who modified this record.', max_length=64)),
                ('petal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Petal')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.MysqlDatabase')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='mysqldatabase',
            name='petals',
            field=models.ManyToManyField(through='flowerhub.MysqlDatabaseRunner', to='flowerhub.Petal'),
        ),
        migrations.CreateModel(
            name='MailingListRunner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_status', models.SmallIntegerField(choices=[(1, 'queued'), (2, 'in progress'), (3, 'active'), (4, 'disabled'), (5, 'deleted')], db_index=True, default=1)),
                ('desired_status', models.SmallIntegerField(choices=[(3, 'active'), (4, 'disabled'), (5, 'deleted')], default=3)),
                ('nonce', models.CharField(help_text='A random string used to authenticate the petal response after attempting to create/edit/delete the resource on the petal.', max_length=64)),
                ('nonce_created', models.DateTimeField(auto_now_add=True, help_text='The date/time the nonce was created.')),
                ('nonce_consumed', models.DateTimeField(blank=True, help_text='The date/time the nonce was used.', null=True)),
                ('data', models.TextField(help_text='A text representation of the resource fields and values to be created.')),
                ('petal_action', models.SmallIntegerField(choices=[(1, 'No operation required.'), (2, 'Create or update LDAP login'), (3, 'Delete LDAP login'), (4, 'Disable LDAP login'), (5, 'Add email address to LDAP record'), (7, 'Remove or disable email address from LDAP record.'), (8, 'Remove or disable last email address from LDAP record.'), (9, 'Create or update a domain zone.'), (10, 'Delete a domain zone.'), (12, 'Ensure Maildir exists.'), (13, 'Delete Maildir.'), (6, 'Add email domain.'), (11, 'Remove email domain.'), (14, 'Add email alias.'), (15, 'Remove email alias.'), (16, 'Create website on origin server.'), (17, 'Disable website on origin server.'), (18, 'Delete website on origin server.')], help_text='The class responsible for implementing this action on the petal.')),
                ('error', models.CharField(blank=True, help_text='Any errors encountered when creating the resource.', max_length=254)),
                ('is_active', models.BooleanField(default=True, help_text='When a resource is re-edited, all previous runners are retired so we always know which ones are active.')),
                ('modified_by', models.CharField(blank=True, help_text='String username of the user who modified this record.', max_length=64)),
                ('petal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Petal')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.MailingList')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MailingListDomain',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('label', models.CharField(blank=True, help_text="Typically, mailing list domain names use 'lists' as the label, so the complete domain name is something like lists.group.org.", max_length=254)),
                ('domain_zone', models.ForeignKey(help_text='Choose the domain zone you want to use for your mailing list.', on_delete=django.db.models.deletion.CASCADE, to='flowerhub.DomainZone')),
                ('member', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='mailinglist',
            name='mailing_list_domain',
            field=models.ForeignKey(help_text='Select from the list of domains that are designated to be used for email lists.', on_delete=django.db.models.deletion.CASCADE, to='flowerhub.MailingListDomain'),
        ),
        migrations.AddField(
            model_name='mailinglist',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member'),
        ),
        migrations.AddField(
            model_name='mailinglist',
            name='petals',
            field=models.ManyToManyField(through='flowerhub.MailingListRunner', to='flowerhub.Petal'),
        ),
        migrations.CreateModel(
            name='LoginRunner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_status', models.SmallIntegerField(choices=[(1, 'queued'), (2, 'in progress'), (3, 'active'), (4, 'disabled'), (5, 'deleted')], db_index=True, default=1)),
                ('desired_status', models.SmallIntegerField(choices=[(3, 'active'), (4, 'disabled'), (5, 'deleted')], default=3)),
                ('nonce', models.CharField(help_text='A random string used to authenticate the petal response after attempting to create/edit/delete the resource on the petal.', max_length=64)),
                ('nonce_created', models.DateTimeField(auto_now_add=True, help_text='The date/time the nonce was created.')),
                ('nonce_consumed', models.DateTimeField(blank=True, help_text='The date/time the nonce was used.', null=True)),
                ('data', models.TextField(help_text='A text representation of the resource fields and values to be created.')),
                ('petal_action', models.SmallIntegerField(choices=[(1, 'No operation required.'), (2, 'Create or update LDAP login'), (3, 'Delete LDAP login'), (4, 'Disable LDAP login'), (5, 'Add email address to LDAP record'), (7, 'Remove or disable email address from LDAP record.'), (8, 'Remove or disable last email address from LDAP record.'), (9, 'Create or update a domain zone.'), (10, 'Delete a domain zone.'), (12, 'Ensure Maildir exists.'), (13, 'Delete Maildir.'), (6, 'Add email domain.'), (11, 'Remove email domain.'), (14, 'Add email alias.'), (15, 'Remove email alias.'), (16, 'Create website on origin server.'), (17, 'Disable website on origin server.'), (18, 'Delete website on origin server.')], help_text='The class responsible for implementing this action on the petal.')),
                ('error', models.CharField(blank=True, help_text='Any errors encountered when creating the resource.', max_length=254)),
                ('is_active', models.BooleanField(default=True, help_text='When a resource is re-edited, all previous runners are retired so we always know which ones are active.')),
                ('modified_by', models.CharField(blank=True, help_text='String username of the user who modified this record.', max_length=64)),
                ('petal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Petal')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.Login')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='login',
            name='mail_store',
            field=models.ForeignKey(blank=True, help_text='The canonical mail host holding this mailbox. Set automatically to default if left blank, only change-able by admins.', limit_choices_to={'category': 7}, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='logins', to='flowerhub.Petal'),
        ),
        migrations.AddField(
            model_name='login',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member'),
        ),
        migrations.AddField(
            model_name='login',
            name='partition',
            field=models.ForeignKey(blank=True, help_text="The partition holding this mailbox's data. Set automatically to default if left blank, only change-able by admins.", limit_choices_to=models.Q(petal__category=7), null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='logins', to='flowerhub.Partition'),
        ),
        migrations.AddField(
            model_name='login',
            name='petals',
            field=models.ManyToManyField(through='flowerhub.LoginRunner', to='flowerhub.Petal'),
        ),
        migrations.CreateModel(
            name='EmailMailboxRunner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_status', models.SmallIntegerField(choices=[(1, 'queued'), (2, 'in progress'), (3, 'active'), (4, 'disabled'), (5, 'deleted')], db_index=True, default=1)),
                ('desired_status', models.SmallIntegerField(choices=[(3, 'active'), (4, 'disabled'), (5, 'deleted')], default=3)),
                ('nonce', models.CharField(help_text='A random string used to authenticate the petal response after attempting to create/edit/delete the resource on the petal.', max_length=64)),
                ('nonce_created', models.DateTimeField(auto_now_add=True, help_text='The date/time the nonce was created.')),
                ('nonce_consumed', models.DateTimeField(blank=True, help_text='The date/time the nonce was used.', null=True)),
                ('data', models.TextField(help_text='A text representation of the resource fields and values to be created.')),
                ('petal_action', models.SmallIntegerField(choices=[(1, 'No operation required.'), (2, 'Create or update LDAP login'), (3, 'Delete LDAP login'), (4, 'Disable LDAP login'), (5, 'Add email address to LDAP record'), (7, 'Remove or disable email address from LDAP record.'), (8, 'Remove or disable last email address from LDAP record.'), (9, 'Create or update a domain zone.'), (10, 'Delete a domain zone.'), (12, 'Ensure Maildir exists.'), (13, 'Delete Maildir.'), (6, 'Add email domain.'), (11, 'Remove email domain.'), (14, 'Add email alias.'), (15, 'Remove email alias.'), (16, 'Create website on origin server.'), (17, 'Disable website on origin server.'), (18, 'Delete website on origin server.')], help_text='The class responsible for implementing this action on the petal.')),
                ('error', models.CharField(blank=True, help_text='Any errors encountered when creating the resource.', max_length=254)),
                ('is_active', models.BooleanField(default=True, help_text='When a resource is re-edited, all previous runners are retired so we always know which ones are active.')),
                ('modified_by', models.CharField(blank=True, help_text='String username of the user who modified this record.', max_length=64)),
                ('petal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Petal')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.EmailMailbox')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='emailmailbox',
            name='login',
            field=models.ForeignKey(help_text='The login to which all all email should be delivered.', on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Login'),
        ),
        migrations.AddField(
            model_name='emailmailbox',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member'),
        ),
        migrations.AddField(
            model_name='emailmailbox',
            name='petals',
            field=models.ManyToManyField(through='flowerhub.EmailMailboxRunner', to='flowerhub.Petal'),
        ),
        migrations.CreateModel(
            name='EmailAliasRunner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_status', models.SmallIntegerField(choices=[(1, 'queued'), (2, 'in progress'), (3, 'active'), (4, 'disabled'), (5, 'deleted')], db_index=True, default=1)),
                ('desired_status', models.SmallIntegerField(choices=[(3, 'active'), (4, 'disabled'), (5, 'deleted')], default=3)),
                ('nonce', models.CharField(help_text='A random string used to authenticate the petal response after attempting to create/edit/delete the resource on the petal.', max_length=64)),
                ('nonce_created', models.DateTimeField(auto_now_add=True, help_text='The date/time the nonce was created.')),
                ('nonce_consumed', models.DateTimeField(blank=True, help_text='The date/time the nonce was used.', null=True)),
                ('data', models.TextField(help_text='A text representation of the resource fields and values to be created.')),
                ('petal_action', models.SmallIntegerField(choices=[(1, 'No operation required.'), (2, 'Create or update LDAP login'), (3, 'Delete LDAP login'), (4, 'Disable LDAP login'), (5, 'Add email address to LDAP record'), (7, 'Remove or disable email address from LDAP record.'), (8, 'Remove or disable last email address from LDAP record.'), (9, 'Create or update a domain zone.'), (10, 'Delete a domain zone.'), (12, 'Ensure Maildir exists.'), (13, 'Delete Maildir.'), (6, 'Add email domain.'), (11, 'Remove email domain.'), (14, 'Add email alias.'), (15, 'Remove email alias.'), (16, 'Create website on origin server.'), (17, 'Disable website on origin server.'), (18, 'Delete website on origin server.')], help_text='The class responsible for implementing this action on the petal.')),
                ('error', models.CharField(blank=True, help_text='Any errors encountered when creating the resource.', max_length=254)),
                ('is_active', models.BooleanField(default=True, help_text='When a resource is re-edited, all previous runners are retired so we always know which ones are active.')),
                ('modified_by', models.CharField(blank=True, help_text='String username of the user who modified this record.', max_length=64)),
                ('petal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Petal')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.EmailAlias')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='emailalias',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member'),
        ),
        migrations.AddField(
            model_name='emailalias',
            name='petals',
            field=models.ManyToManyField(through='flowerhub.EmailAliasRunner', to='flowerhub.Petal'),
        ),
        migrations.CreateModel(
            name='DomainZoneRunner',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('current_status', models.SmallIntegerField(choices=[(1, 'queued'), (2, 'in progress'), (3, 'active'), (4, 'disabled'), (5, 'deleted')], db_index=True, default=1)),
                ('desired_status', models.SmallIntegerField(choices=[(3, 'active'), (4, 'disabled'), (5, 'deleted')], default=3)),
                ('nonce', models.CharField(help_text='A random string used to authenticate the petal response after attempting to create/edit/delete the resource on the petal.', max_length=64)),
                ('nonce_created', models.DateTimeField(auto_now_add=True, help_text='The date/time the nonce was created.')),
                ('nonce_consumed', models.DateTimeField(blank=True, help_text='The date/time the nonce was used.', null=True)),
                ('data', models.TextField(help_text='A text representation of the resource fields and values to be created.')),
                ('petal_action', models.SmallIntegerField(choices=[(1, 'No operation required.'), (2, 'Create or update LDAP login'), (3, 'Delete LDAP login'), (4, 'Disable LDAP login'), (5, 'Add email address to LDAP record'), (7, 'Remove or disable email address from LDAP record.'), (8, 'Remove or disable last email address from LDAP record.'), (9, 'Create or update a domain zone.'), (10, 'Delete a domain zone.'), (12, 'Ensure Maildir exists.'), (13, 'Delete Maildir.'), (6, 'Add email domain.'), (11, 'Remove email domain.'), (14, 'Add email alias.'), (15, 'Remove email alias.'), (16, 'Create website on origin server.'), (17, 'Disable website on origin server.'), (18, 'Delete website on origin server.')], help_text='The class responsible for implementing this action on the petal.')),
                ('error', models.CharField(blank=True, help_text='Any errors encountered when creating the resource.', max_length=254)),
                ('is_active', models.BooleanField(default=True, help_text='When a resource is re-edited, all previous runners are retired so we always know which ones are active.')),
                ('modified_by', models.CharField(blank=True, help_text='String username of the user who modified this record.', max_length=64)),
                ('petal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Petal')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='flowerhub.DomainZone')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='domainzone',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member'),
        ),
        migrations.AddField(
            model_name='domainzone',
            name='petals',
            field=models.ManyToManyField(through='flowerhub.DomainZoneRunner', to='flowerhub.Petal'),
        ),
        migrations.AddField(
            model_name='domainname',
            name='domain_zone',
            field=models.ForeignKey(help_text='The base domain, e.g. mayfirst.coop or fightback.org.', on_delete=django.db.models.deletion.CASCADE, to='flowerhub.DomainZone'),
        ),
        migrations.AddField(
            model_name='domainname',
            name='member',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member'),
        ),
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('first_name', models.CharField(max_length=64)),
                ('last_name', models.CharField(max_length=64)),
                ('email', models.EmailField(max_length=254)),
                ('is_billing', models.BooleanField(default=True)),
                ('member', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Access',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.SmallIntegerField(choices=[(1, 'Active'), (0, 'User disabled'), (-1, 'Auto disabled')], db_index=True, default=1)),
                ('login', models.ForeignKey(help_text="Choose from a list of your membership's logins or type in any login username available in the control panel. It does not have to be a login in your membership. The person who controls the login will have full access to your membership.", on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Login')),
                ('member', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.Member')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MailingListDomainMap',
            fields=[
                ('domain_name', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to='flowerhub.DomainName')),
                ('mailing_list_domain', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='flowerhub.MailingListDomain')),
            ],
        ),
    ]
